@@ -3,26 +3,25 @@ package MIME::Expander::Plugin::ApplicationGzip;
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use parent qw(MIME::Expander::Plugin);
 __PACKAGE__->mk_classdata('ACCEPT_TYPES' => [qw(
     application/gzip
-    application/x-gzip
     )]);
 
 use IO::Uncompress::Gunzip;
 
 sub expand {
     my $self        = shift;
-    my $contents    = shift;
+    my $part        = shift;
     my $callback    = shift;
     my $c           = 0;
 
+    my $contents = $part->body;
     my $z = IO::Uncompress::Gunzip->new(
-        ref $contents eq 'SCALAR' ? $contents : \$contents
-        , Append => 1)
-        or die "gunzip failed: $IO::Uncompress::Gunzip::GunzipError";
+        \$contents, Append => 1
+        ) or die "gunzip failed: $IO::Uncompress::Gunzip::GunzipError";
 
     my $buf;
     1 while( 0 < $z->read($buf) );
@@ -49,8 +48,8 @@ MIME::Expander::Plugin::ApplicationGzip - a plugin for MIME::Expander
 =head1 SYNOPSIS
 
     my $expander = MIME::Expander::Plugin::ApplicationGzip->new;
-    $expander->expand(\$data, sub {
-            my $ref_expanded_data = shift;
+    $expander->expand($part, sub {
+            my $contents = shift;
             my $metadata = shift || {};
             print $metadata->{content_type}, "\n";
             print $metadata->{filename}, "\n";
