@@ -3,12 +3,11 @@ package MIME::Expander::Plugin::ApplicationTar;
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use parent qw(MIME::Expander::Plugin);
 __PACKAGE__->mk_classdata('ACCEPT_TYPES' => [qw(
     application/tar
-    application/x-tar
     )]);
 
 use Archive::Tar;
@@ -16,12 +15,13 @@ use IO::Scalar;
 
 sub expand {
     my $self        = shift;
-    my $contents    = shift;
+    my $part        = shift;
     my $callback    = shift;
     my $c           = 0;
 
+    my $contents = $part->body;
     my $iter = Archive::Tar->iter(IO::Scalar->new(
-        ref $contents eq 'SCALAR' ? $contents : \$contents
+        \$contents,
         ));
     while( my $f = $iter->() ){
         if( $f->has_content and $f->validate ){
@@ -48,8 +48,8 @@ MIME::Expander::Plugin::ApplicationTar - a plugin for MIME::Expander
 =head1 SYNOPSIS
 
     my $expander = MIME::Expander::Plugin::ApplicationTar->new;
-    $expander->expand(\$data, sub {
-            my $ref_expanded_data = shift;
+    $expander->expand($part, sub {
+            my $contents = shift;
             my $metadata = shift || {};
             print $metadata->{content_type}, "\n";
             print $metadata->{filename}, "\n";
